==> simphone-src-0.8.2.zip: simphone/qsimphone/translations/qsimphone_en.ts <==
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>ChatFrame</name>
    <message>
        <source>Force delete of this message when I push &quot;%1&quot;</source>
        <translation>Force delete of this message when I push “%1”</translation>
    </message>
    <message>
        <source>Right-click your chat history and choose &quot;Show More&quot; to reload it and then try again.</source>
        <translation>Right-click your chat history and choose “Show More” to reload it and then try again.</translation>
    </message>
    <message numerus="yes">
        <source>%1 out of %n message(s) could not be deleted.</source>
        <translation>
            <numerusform>%1 out of %n message could not be deleted.</numerusform>
            <numerusform>%1 out of %n messages could not be deleted.</numerusform>
        </translation>
    </message>
    <message>
        <source>Force delete of partially-accessible messages when I push &quot;%1&quot;</source>
        <translation>Force delete of partially-accessible messages when I push “%1”</translation>
    </message>
</context>
<context>
    <name>Contacts</name>
    <message>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Francais</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <source>If you proceed, this contact will become &quot;NOT VERIFIED&quot;.</source>
        <translation>If you proceed, this contact will become “NOT VERIFIED”.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;br/&gt;&lt;span style=&quot; color:#ff0000;&quot;&gt;Some of your chosen audio devices have become invalid.&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;Please, plug the device back in or hang up your audio call and choose a valid device from the &quot;Main&quot; menu &quot;Settings&quot;.&lt;br/&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;br/&gt;&lt;span style=&quot; color:#ff0000;&quot;&gt;Some of your chosen audio devices have become invalid.&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;Please, plug the device back in or hang up your audio call and choose a valid device from the “Main” menu “Settings”.&lt;br/&gt;&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Generate</name>
    <message>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Francais</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
</context>
<context>
    <name>KeyGen</name>
    <message>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Francais</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
</context>
<context>
    <name>Login</name>
    <message>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Francais</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
</context>
<context>
    <name>SeedGen</name>
    <message>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Francais</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <source>&lt;br/&gt;&lt;br/&gt;Simphone did not hear you talking; something is wrong with your audio recording settings. &lt;span style=&quot; color:#ff0000;&quot;&gt;&lt;b&gt;Check that your microphone is working, connected to your audio device, and not muted.&lt;/b&gt;&lt;/span&gt; If you have multiple audio devices, you can choose the one to use from the &quot;Login&quot; menu.</source>
        <translation>&lt;br/&gt;&lt;br/&gt;Simphone did not hear you talking; something is wrong with your audio recording settings. &lt;span style=&quot; color:#ff0000;&quot;&gt;&lt;b&gt;Check that your microphone is working, connected to your audio device, and not muted.&lt;/b&gt;&lt;/span&gt; If you have multiple audio devices, you can choose the one to use from the “Login” menu.</translation>
    </message>
    <message>
        <source>

Make sure that your audio device is connected to the computer and not disabled. If you have multiple audio devices, you can choose the one to use from the &quot;Login&quot; menu.</source>
        <translation>

Make sure that your audio device is connected to the computer and not disabled. If you have multiple audio devices, you can choose the one to use from the “Login” menu.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Show me as &quot;away&quot;, when I&apos;ve been inactive for </source>
        <translation>Show me as “away”, when I&apos;ve been inactive for </translation>
    </message>
    <message>
        <source>Playing of sound &quot;%1&quot; not successful (%2)</source>
        <translation>Playing of sound “%1” not successful (%2)</translation>
    </message>
    <message>
        <source>Plug the device back in or hang up your audio call and choose a valid device from the &quot;Audio&quot; tab of &quot;Settings&quot;.</source>
        <translation>Plug the device back in or hang up your audio call and choose a valid device from the “Audio” tab of “Settings”.</translation>
    </message>
</context>
<context>
    <name>ShowSeed</name>
    <message>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Francais</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
</context>
<context>
    <name>ContactInfo</name>
    <message>
        <source>You can set your DynDNS hostname from the &quot;Network&quot; tab of &quot;Settings&quot;.</source>
        <translation>You can set your DynDNS hostname from the “Network” tab of “Settings”.</translation>
    </message>
    <message>
        <source>You can see your location from the &quot;Info&quot;, after right-clicking on the user &quot;test&quot;.</source>
        <translation>You can see your location from the “Info”, after right-clicking on the user “test”.</translation>
    </message>
    <message>
        <source>You can set your preferred ciphers from the &quot;Security&quot; tab of &quot;Settings&quot;.</source>
        <translation>You can set your preferred ciphers from the “Security” tab of “Settings”.</translation>
    </message>
    <message numerus="yes">
        <source>Connected %n time(s) to %1 for %2, since Simphone started.</source>
        <translation>
            <numerusform>Connected only once to %1 for %2, since Simphone started.</numerusform>
            <numerusform>Connected %n times to %1 for %2, since Simphone started.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Previously connected %n time(s) to %1 for %2.</source>
        <translation>
            <numerusform>Previously connected only once to %1 for %2.</numerusform>
            <numerusform>Previously connected %n times to %1 for %2.</numerusform>
        </translation>
    </message>
    <message>
        <source>Add &quot;Show All&quot; to chat menu.</source>
        <translation>Add “Show All” to chat menu.</translation>
    </message>
    <message>
        <source>&quot;Show All&quot; in chat menu</source>
        <translation>“Show All” in chat menu</translation>
    </message>
</context>
<context>
    <name>Contact</name>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation>
            <numerusform>%n week</numerusform>
            <numerusform>%n weeks</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n day</numerusform>
            <numerusform>%n days</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n hour</numerusform>
            <numerusform>%n hours</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation>
            <numerusform>%n minute</numerusform>
            <numerusform>%n minutes</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n second</numerusform>
            <numerusform>%n seconds</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SimCore</name>
    <message>
        <source>The incoming port number you have set is not available. Either quit the application, which is using this port or change the port number from the &quot;Network&quot; tab of &quot;Settings&quot;.</source>
        <translation>The incoming port number you have set is not available. Either quit the application, which is using this port or change the port number from the “Network” tab of “Settings”.</translation>
    </message>
    <message>
        <source>The &quot;localhost&quot; network interface is not available.</source>
        <translation>The “localhost” network interface is not available.</translation>
    </message>
    <message>
        <source>You have been logged off, because of multiple login.

Change your status back to &quot;online&quot; manually as soon as you are back at the computer.</source>
        <translation>You have been logged off, because of multiple login.

Change your status back to “online” manually as soon as you are back at the computer.</translation>
    </message>
    <message>
        <source>%1 uses undesired cipher &quot;%2&quot;.</source>
        <translation>%1 uses undesired cipher “%2”.</translation>
    </message>
    <message>
        <source>%1 uses insecure system &quot;%2&quot;.</source>
        <translation>%1 uses insecure system “%2”.</translation>
    </message>
    <message>
        <source>You should change your status back to &quot;online&quot; afterwards.</source>
        <translation>You should change your status back to “online” afterwards.</translation>
    </message>
    <message>
        <source>Your computer or Simphone may have suffered a crash. The &lt;b&gt;&quot;%1&quot;&lt;/b&gt; file prevents you from logging in.&lt;br/&gt;&lt;br/&gt;Push &lt;b&gt;%2&lt;/b&gt; to remove the damaged file and try to login again. You may have to do so multiple times, in case there are multiple problems.&lt;br/&gt;&lt;br/&gt;If you push &lt;b&gt;%3&lt;/b&gt;, Simphone is going to exit immediately without logging you in or touching your files.&lt;br/&gt;&lt;br/&gt;Do you want to permanently remove the &lt;b&gt;&quot;%1&quot;&lt;/b&gt; file now?</source>
        <translation>Your computer or Simphone may have suffered a crash. The &lt;b&gt;“%1”&lt;/b&gt; file prevents you from logging in.&lt;br/&gt;&lt;br/&gt;Push &lt;b&gt;%2&lt;/b&gt; to remove the damaged file and try to login again. You may have to do so multiple times, in case there are multiple problems.&lt;br/&gt;&lt;br/&gt;If you push &lt;b&gt;%3&lt;/b&gt;, Simphone is going to exit immediately without logging you in or touching your files.&lt;br/&gt;&lt;br/&gt;Do you want to permanently remove the &lt;b&gt;“%1”&lt;/b&gt; file now?</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Simphone did not hear you talking.&lt;/b&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot; color:#ff0000;&quot;&gt;Check that your microphone is working, connected to your audio device, and not muted.&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;You can ignore this warning if your contact hears you talking. Otherwise, you can hang up your audio call and choose the correct microphone device from the &quot;Main&quot; menu &quot;Settings&quot;. The &lt;b&gt;Start Audio Test&lt;/b&gt; button will help you check whether your microphone is working.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Simphone did not hear you talking.&lt;/b&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot; color:#ff0000;&quot;&gt;Check that your microphone is working, connected to your audio device, and not muted.&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;You can ignore this warning if your contact hears you talking. Otherwise, you can hang up your audio call and choose the correct microphone device from the “Main” menu “Settings”. The &lt;b&gt;Start Audio Test&lt;/b&gt; button will help you check whether your microphone is working.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>If your audio device has a problem, try to fix it as described in the user manual &lt;b&gt;Audio Device Troubleshooting&lt;/b&gt; chapter from the &quot;Help&quot; menu.</source>
        <translation>If your audio device has a problem, try to fix it as described in the user manual &lt;b&gt;Audio Device Troubleshooting&lt;/b&gt; chapter from the “Help” menu.</translation>
    </message>
    <message>
        <source>If you could not hear anything, maybe you have a problem with your internet connection. Try to reduce the &lt;b&gt;Audio call sampling rate&lt;/b&gt; from the &quot;Main&quot; menu &quot;Settings&quot; and see if there is any improvement.</source>
        <translation>If you could not hear anything, maybe you have a problem with your internet connection. Try to reduce the &lt;b&gt;Audio call sampling rate&lt;/b&gt; from the “Main” menu “Settings” and see if there is any improvement.</translation>
    </message>
</context>
</TS>

==> simphone-src-0.9.1.zip: simphone/qsimphone/translations/qsimphone_en.ts <==
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>ChatFrame</name>
    <message>
        <source>Force delete of this message when I push &quot;%1&quot;</source>
        <translation>Force delete of this message when I push “%1”</translation>
    </message>
    <message>
        <source>Right-click your chat history and choose &quot;Show More&quot; to reload it and then try again.</source>
        <translation>Right-click your chat history and choose “Show More” to reload it and then try again.</translation>
    </message>
    <message numerus="yes">
        <source>%1 out of %n message(s) could not be deleted.</source>
        <translation>
            <numerusform>%1 out of %n message could not be deleted.</numerusform>
            <numerusform>%1 out of %n messages could not be deleted.</numerusform>
        </translation>
    </message>
    <message>
        <source>Force delete of partially-accessible messages when I push &quot;%1&quot;</source>
        <translation>Force delete of partially-accessible messages when I push “%1”</translation>
    </message>
</context>
<context>
    <name>Contacts</name>
    <message>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Francais</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
    <message numerus="yes">
        <source>You have %n outgoing file transfer(s) with %1 that are currently active.</source>
        <translation>
            <numerusform>You have %n outgoing file transfer with %1 that is currently active.</numerusform>
            <numerusform>You have %n outgoing file transfers with %1 that are currently active.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Please, cancel the transfer(s) before deleting &lt;b&gt;%1&lt;/b&gt;.</source>
        <translation>
            <numerusform>Please, cancel the transfer before deleting &lt;b&gt;%1&lt;/b&gt;.</numerusform>
            <numerusform>Please, cancel the transfers before deleting &lt;b&gt;%1&lt;/b&gt;.</numerusform>
        </translation>
    </message>
    <message>
        <source>If you proceed, this contact will become &quot;NOT VERIFIED&quot;.</source>
        <translation>If you proceed, this contact will become “NOT VERIFIED”.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;br/&gt;&lt;span style=&quot; color:#ff0000;&quot;&gt;Some of your chosen audio devices have become invalid.&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;Please, plug the device back in or hang up your audio call and choose a valid device from the &quot;Main&quot; menu &quot;Settings&quot;.&lt;br/&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;br/&gt;&lt;span style=&quot; color:#ff0000;&quot;&gt;Some of your chosen audio devices have become invalid.&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;Please, plug the device back in or hang up your audio call and choose a valid device from the “Main” menu “Settings”.&lt;br/&gt;&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Generate</name>
    <message>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Francais</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
</context>
<context>
    <name>KeyGen</name>
    <message>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Francais</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
</context>
<context>
    <name>Login</name>
    <message>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Francais</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
</context>
<context>
    <name>SeedGen</name>
    <message>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Francais</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <source>&lt;br/&gt;&lt;br/&gt;Simphone did not hear you talking; something is wrong with your audio recording settings. &lt;span style=&quot; color:#ff0000;&quot;&gt;&lt;b&gt;Check that your microphone is working, connected to your audio device, and not muted.&lt;/b&gt;&lt;/span&gt; If you have multiple audio devices, you can choose the one to use from the &quot;Login&quot; menu.</source>
        <translation>&lt;br/&gt;&lt;br/&gt;Simphone did not hear you talking; something is wrong with your audio recording settings. &lt;span style=&quot; color:#ff0000;&quot;&gt;&lt;b&gt;Check that your microphone is working, connected to your audio device, and not muted.&lt;/b&gt;&lt;/span&gt; If you have multiple audio devices, you can choose the one to use from the “Login” menu.</translation>
    </message>
    <message>
        <source>

Make sure that your audio device is connected to the computer and not disabled. If you have multiple audio devices, you can choose the one to use from the &quot;Login&quot; menu.</source>
        <translation>

Make sure that your audio device is connected to the computer and not disabled. If you have multiple audio devices, you can choose the one to use from the “Login” menu.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Show me as &quot;away&quot;, when I&apos;ve been inactive for </source>
        <translation>Show me as “away”, when I&apos;ve been inactive for </translation>
    </message>
    <message>
        <source>Playing of sound &quot;%1&quot; not successful (%2)</source>
        <translation>Playing of sound “%1” not successful (%2)</translation>
    </message>
    <message>
        <source>Plug the device back in or hang up your audio call and choose a valid device from the &quot;Audio&quot; tab of &quot;Settings&quot;.</source>
        <translation>Plug the device back in or hang up your audio call and choose a valid device from the “Audio” tab of “Settings”.</translation>
    </message>
</context>
<context>
    <name>ShowSeed</name>
    <message>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Francais</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
</context>
<context>
    <name>Transfers</name>
    <message numerus="yes">
        <source>You have selected &lt;b&gt;%n received file(s)&lt;/b&gt; to cancel.</source>
        <translation>
            <numerusform>You have selected &lt;b&gt;%n received file&lt;/b&gt; to cancel.</numerusform>
            <numerusform>You have selected &lt;b&gt;%n received files&lt;/b&gt; to cancel.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>You have selected &lt;b&gt;%n sent file(s)&lt;/b&gt; to cancel.</source>
        <translation>
            <numerusform>You have selected &lt;b&gt;%n sent file&lt;/b&gt; to cancel.</numerusform>
            <numerusform>You have selected &lt;b&gt;%n sent files&lt;/b&gt; to cancel.</numerusform>
        </translation>
    </message>
    <message>
        <source>Are you sure you want to &lt;b&gt;cancel&lt;/b&gt; the file transfer of &quot;%1&quot;?</source>
        <translation>Are you sure you want to &lt;b&gt;cancel&lt;/b&gt; the file transfer of “%1”?</translation>
    </message>
    <message numerus="yes">
        <source>You have selected &lt;b&gt;%n sent file(s)&lt;/b&gt; to remove from this list.</source>
        <translation>
            <numerusform>You have selected &lt;b&gt;%n sent file&lt;/b&gt; to remove from this list.</numerusform>
            <numerusform>You have selected &lt;b&gt;%n sent files&lt;/b&gt; to remove from this list.</numerusform>
        </translation>
    </message>
    <message>
        <source>Sent file &quot;%1&quot; could not be removed.</source>
        <translation>Sent file “%1” could not be removed.</translation>
    </message>
    <message>
        <source>Cancelling file transfer of &quot;%1&quot; not successful (%2)</source>
        <translation>Cancelling file transfer of “%1” not successful (%2)</translation>
    </message>
    <message numerus="yes">
        <source>You have %n incoming file transfer(s) that are currently active.</source>
        <translation>
            <numerusform>You have %n incoming file transfer that is currently active.</numerusform>
            <numerusform>You have %n incoming file transfers that are currently active.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Please, wait for this transfer to finish or cancel it before changing the download directory.</source>
        <translation>
            <numerusform>Please, wait for this transfer to finish or cancel it before changing the download directory.</numerusform>
            <numerusform>Please, wait for these transfers to finish or cancel them before changing the download directory.</numerusform>
        </translation>
    </message>
    <message>
        <source>&lt;p&gt;Please, push the &lt;b&gt;Change Download Directory&lt;/b&gt; button from the &quot;File&quot; tab of &quot;Settings&quot; at any time later.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Please, push the &lt;b&gt;Change Download Directory&lt;/b&gt; button from the “File” tab of “Settings” at any time later.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;To do so, push the &lt;b&gt;Change Download Directory&lt;/b&gt; button from the &quot;File&quot; tab of &quot;Settings&quot;.&lt;/p&gt;</source>
        <translation>&lt;p&gt;To do so, push the &lt;b&gt;Change Download Directory&lt;/b&gt; button from the “File” tab of “Settings”.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Sending of file &quot;%1&quot; not successful (%2)</source>
        <translation>Sending of file “%1” not successful (%2)</translation>
    </message>
</context>
<context>
    <name>ContactInfo</name>
    <message>
        <source>You can set your DynDNS hostname from the &quot;Network&quot; tab of &quot;Settings&quot;.</source>
        <translation>You can set your DynDNS hostname from the “Network” tab of “Settings”.</translation>
    </message>
    <message>
        <source>You can see your location from the &quot;Info&quot;, after right-clicking on the user &quot;test&quot;.</source>
        <translation>You can see your location from the “Info”, after right-clicking on the user “test”.</translation>
    </message>
    <message>
        <source>You can set your preferred ciphers from the &quot;Security&quot; tab of &quot;Settings&quot;.</source>
        <translation>You can set your preferred ciphers from the “Security” tab of “Settings”.</translation>
    </message>
    <message numerus="yes">
        <source>Connected %n time(s) to %1 for %2, since Simphone started.</source>
        <translation>
            <numerusform>Connected only once to %1 for %2, since Simphone started.</numerusform>
            <numerusform>Connected %n times to %1 for %2, since Simphone started.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Previously connected %n time(s) to %1 for %2.</source>
        <translation>
            <numerusform>Previously connected only once to %1 for %2.</numerusform>
            <numerusform>Previously connected %n times to %1 for %2.</numerusform>
        </translation>
    </message>
    <message>
        <source>Add &quot;Show All&quot; to chat menu.</source>
        <translation>Add “Show All” to chat menu.</translation>
    </message>
    <message>
        <source>&quot;Show All&quot; in chat menu</source>
        <translation>“Show All” in chat menu</translation>
    </message>
</context>
<context>
    <name>Contact</name>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation>
            <numerusform>%n week</numerusform>
            <numerusform>%n weeks</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n day</numerusform>
            <numerusform>%n days</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n hour</numerusform>
            <numerusform>%n hours</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation>
            <numerusform>%n minute</numerusform>
            <numerusform>%n minutes</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n second</numerusform>
            <numerusform>%n seconds</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>MessagesModel</name>
    <message numerus="yes">
        <source>File size = %n byte(s)</source>
        <translation>
            <numerusform>File size = %n byte</numerusform>
            <numerusform>File size = %n bytes</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SimCore</name>
    <message>
        <source>The incoming port number you have set is not available. Either quit the application, which is using this port or change the port number from the &quot;Network&quot; tab of &quot;Settings&quot;.</source>
        <translation>The incoming port number you have set is not available. Either quit the application, which is using this port or change the port number from the “Network” tab of “Settings”.</translation>
    </message>
    <message>
        <source>The &quot;localhost&quot; network interface is not available.</source>
        <translation>The “localhost” network interface is not available.</translation>
    </message>
    <message>
        <source>You have been logged off, because of multiple login.

Change your status back to &quot;online&quot; manually as soon as you are back at the computer.</source>
        <translation>You have been logged off, because of multiple login.

Change your status back to “online” manually as soon as you are back at the computer.</translation>
    </message>
    <message>
        <source>%1 uses undesired cipher &quot;%2&quot;.</source>
        <translation>%1 uses undesired cipher “%2”.</translation>
    </message>
    <message>
        <source>%1 uses insecure system &quot;%2&quot;.</source>
        <translation>%1 uses insecure system “%2”.</translation>
    </message>
    <message>
        <source>You should change your status back to &quot;online&quot; afterwards.</source>
        <translation>You should change your status back to “online” afterwards.</translation>
    </message>
    <message>
        <source>Your computer or Simphone may have suffered a crash. The &lt;b&gt;&quot;%1&quot;&lt;/b&gt; file prevents you from logging in.&lt;br/&gt;&lt;br/&gt;Push &lt;b&gt;%2&lt;/b&gt; to remove the damaged file and try to login again. You may have to do so multiple times, in case there are multiple problems.&lt;br/&gt;&lt;br/&gt;If you push &lt;b&gt;%3&lt;/b&gt;, Simphone is going to exit immediately without logging you in or touching your files.&lt;br/&gt;&lt;br/&gt;Do you want to permanently remove the &lt;b&gt;&quot;%1&quot;&lt;/b&gt; file now?</source>
        <translation>Your computer or Simphone may have suffered a crash. The &lt;b&gt;“%1”&lt;/b&gt; file prevents you from logging in.&lt;br/&gt;&lt;br/&gt;Push &lt;b&gt;%2&lt;/b&gt; to remove the damaged file and try to login again. You may have to do so multiple times, in case there are multiple problems.&lt;br/&gt;&lt;br/&gt;If you push &lt;b&gt;%3&lt;/b&gt;, Simphone is going to exit immediately without logging you in or touching your files.&lt;br/&gt;&lt;br/&gt;Do you want to permanently remove the &lt;b&gt;“%1”&lt;/b&gt; file now?</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Simphone did not hear you talking.&lt;/b&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot; color:#ff0000;&quot;&gt;Check that your microphone is working, connected to your audio device, and not muted.&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;You can ignore this warning if your contact hears you talking. Otherwise, you can hang up your audio call and choose the correct microphone device from the &quot;Main&quot; menu &quot;Settings&quot;. The &lt;b&gt;Start Audio Test&lt;/b&gt; button will help you check whether your microphone is working.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Simphone did not hear you talking.&lt;/b&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot; color:#ff0000;&quot;&gt;Check that your microphone is working, connected to your audio device, and not muted.&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;You can ignore this warning if your contact hears you talking. Otherwise, you can hang up your audio call and choose the correct microphone device from the “Main” menu “Settings”. The &lt;b&gt;Start Audio Test&lt;/b&gt; button will help you check whether your microphone is working.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>If your audio device has a problem, try to fix it as described in the user manual &lt;b&gt;Audio Device Troubleshooting&lt;/b&gt; chapter from the &quot;Help&quot; menu.</source>
        <translation>If your audio device has a problem, try to fix it as described in the user manual &lt;b&gt;Audio Device Troubleshooting&lt;/b&gt; chapter from the “Help” menu.</translation>
    </message>
    <message>
        <source>If you could not hear anything, maybe you have a problem with your internet connection. Try to reduce the &lt;b&gt;Audio call sampling rate&lt;/b&gt; from the &quot;Main&quot; menu &quot;Settings&quot; and see if there is any improvement.</source>
        <translation>If you could not hear anything, maybe you have a problem with your internet connection. Try to reduce the &lt;b&gt;Audio call sampling rate&lt;/b&gt; from the “Main” menu “Settings” and see if there is any improvement.</translation>
    </message>
</context>
</TS>
